#
# spec file for package perl-App-Nopaste
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name App-Nopaste
Name:           perl-App-Nopaste
Version:        1.13.0
Release:        1.1
# 1.013 -> normalize -> 1.13.0
%define cpan_version 1.013
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Easy access to any pastebin
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETHER/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        SusePaste.pm
Source2:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(CPAN::Meta::Requirements) >= 2.121
BuildRequires:  perl(Class::Load)
BuildRequires:  perl(Getopt::Long::Descriptive)
BuildRequires:  perl(JSON::MaybeXS)
BuildRequires:  perl(LWP::Protocol)
BuildRequires:  perl(LWP::UserAgent)
BuildRequires:  perl(Module::Metadata)
BuildRequires:  perl(Module::Pluggable)
BuildRequires:  perl(Module::Runtime)
BuildRequires:  perl(Path::Tiny)
BuildRequires:  perl(Test::Deep)
BuildRequires:  perl(Test::Fatal)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(URI::Escape)
BuildRequires:  perl(WWW::Mechanize)
BuildRequires:  perl(namespace::clean) >= 0.190
BuildRequires:  perl(parent)
Requires:       perl(Class::Load)
Requires:       perl(Getopt::Long::Descriptive)
Requires:       perl(JSON::MaybeXS)
Requires:       perl(LWP::UserAgent)
Requires:       perl(Module::Pluggable)
Requires:       perl(Module::Runtime)
Requires:       perl(Path::Tiny)
Requires:       perl(URI::Escape)
Requires:       perl(WWW::Mechanize)
Requires:       perl(namespace::clean) >= 0.190
Requires:       perl(parent)
Provides:       perl(App::Nopaste) = %{version}
Provides:       perl(App::Nopaste::Command) = %{version}
Provides:       perl(App::Nopaste::Service) = %{version}
Provides:       perl(App::Nopaste::Service::Codepeek) = %{version}
Provides:       perl(App::Nopaste::Service::Debian) = %{version}
Provides:       perl(App::Nopaste::Service::Gist) = %{version}
Provides:       perl(App::Nopaste::Service::GitLab) = %{version}
Provides:       perl(App::Nopaste::Service::Mojopaste) = %{version}
Provides:       perl(App::Nopaste::Service::PastebinCom) = %{version}
Provides:       perl(App::Nopaste::Service::Pastie) = %{version}
Provides:       perl(App::Nopaste::Service::Shadowcat) = %{version}
Provides:       perl(App::Nopaste::Service::Snitch) = %{version}
Provides:       perl(App::Nopaste::Service::Ubuntu) = %{version}
Provides:       perl(App::Nopaste::Service::ssh) = %{version}
%undefine       __perllib_provides
Recommends:     perl(Browser::Open)
Recommends:     perl(Clipboard)
Recommends:     perl(WWW::Pastebin::PastebinCom::Create) >= 1.3
%{perl_requires}

%description
Pastebins (also known as nopaste sites) let you post text, usually code,
for public viewing. They're used a lot in IRC channels to show code that
would normally be too long to give directly in the channel (hence the name
nopaste).

Each pastebin is slightly different. When one pastebin goes down (I'm
looking at you, http://paste.husk.org), then you have to find a new one.
And if you usually use a script to publish text, then it's too much hassle.

This module aims to smooth out the differences between pastebins, and
provides redundancy: if one site doesn't work, it just tries a different
one.

It's also modular: you only need to put on CPAN a
App::Nopaste::Service::Foo module and anyone can begin using it.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644
# MANUAL BEGIN
%__install -m 0644 "%{SOURCE1}" lib/App/Nopaste/Service/
# MANUAL END

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING README
%license LICENSE

%changelog
* Mon Jun 23 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Tue Jul 23 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.013
  see /usr/share/doc/packages/perl-App-Nopaste/Changes
  1.013   2019-07-23 02:00:06Z
  - amended instructions in App::Nopaste::Service::Gist regarding
    creating a gist authorization token
  - --copy now works with Control-V on X windows (PR#17, Shlomi Fish)
* Mon Jul  9 2018 coolo@suse.com
- updated to 1.012
  see /usr/share/doc/packages/perl-App-Nopaste/Changes
* Sun Aug 27 2017 coolo@suse.com
- updated to 1.011
  see /usr/share/doc/packages/perl-App-Nopaste/Changes
  1.011   2017-08-26 20:31:37Z
  - fix formatting of script pod
* Thu Aug  3 2017 coolo@suse.com
- updated to 1.010
  see /usr/share/doc/packages/perl-App-Nopaste/Changes
  1.010   2017-08-02 04:38:50Z
  - fix shebang in 'nopaste' executable
* Sat Apr 15 2017 coolo@suse.com
- updated to 1.009
  see /usr/share/doc/packages/perl-App-Nopaste/Changes
  1.009   2017-04-13 22:08:42Z
  - fixed arguments for the Mojopaste service, to work with the default
    service provider at thorsen.pm (PR#14, Andrew Rodland)
* Tue Feb 28 2017 coolo@suse.com
- updated to 1.008
  see /usr/share/doc/packages/perl-App-Nopaste/Changes
  1.008   2017-02-27 01:05:29Z
  - updated paste URLs for Debian and Ubuntu services (RT#120369, Gregor
    Herrmann)
  - deprecation warning added to the now-defunct Codepeek service
* Sat Sep 17 2016 coolo@suse.com
- updated to 1.007
  see /usr/share/doc/packages/perl-App-Nopaste/Changes
  1.007   2016-09-16 02:26:28Z
  - fix handling of filename option in the Gist command (Zakariyya
    Mughal, PR#13)
* Sat May 28 2016 coolo@suse.com
- updated to 1.006
  see /usr/share/doc/packages/perl-App-Nopaste/Changes
  1.006   2016-05-24 02:55:20Z
  - fix failing tests with other locales, environment settings
  1.005   2016-05-20 02:39:52Z
  - mark App::Nopaste::Service::Codepeek as deprecated in metadata
  - the Gist command also looks in ~/.github for credentials
  - many additional tests; thanks David J. Shultz!
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.004
  see /usr/share/doc/packages/perl-App-Nopaste/Changes
* Sun Feb  9 2014 coolo@suse.com
- updated to 0.96
  - added missing prereqs
  - bumped the minimum version needed for the (optional) prerequisite
    WWW::Pastebin::PastebinCom::Create, to avoid errors in previous
    versions (thanks, Zoffix!)
  - updated and fixed debian and ubuntu language mappings (haarg, PR#1)
  - packaging converted to Dist::Zilla; handling of optional features
    fixed (see RT#91053)
* Wed May 15 2013 coolo@suse.com
- updated to 0.92
    Fix the language mappins for Ubuntu's pastebin (Sergey Romanov)
    Don't need to load Moose in the tests (Sergey Romanov)
    Decode incoming text as utf8 (Jesse Luehrs)
    Support for GITHUB_USER and GITHUB_PASS (Rafael Kitover)
    Name the gist file `nopaste` not `nopaste.txt` for possible syntax highlighting (Rafael Kitover)
    Use decode_json not a regular expression to decode Gist response body (Shawn M Moore)
    Give a hint to perldoc App::Nopaste::Service::Gist on 401 (Shawn M Moore)
    Port from Moose and MooseX::Getopt to Getopt::Long::Descriptive (frew)
    App::Nopaste is not using any interesting Moose features,
    so it doesn't make sense to pay the startup cost (even
    though it's probably dominated by network latency)
    Please report any regressions!
* Tue Sep  4 2012 coolo@suse.com
- updated to 0.35
    Don't barf when gist-ing STDIN. (Ricardo SIGNES)
    Support for GitHub's v3 API [Вячеслав Тихановский (vti)]
* Thu Dec 15 2011 pascal.bleser@opensuse.org
- update to 0.33:
  * support for --description in Gist RT#73272
* Fri Oct 21 2011 pascal.bleser@opensuse.org
- update to 0.32:
  * better error reporting
  * fix some attribution errors [RT#70434]
- changes from 0.31:
  * better filenames for ssh service
- changes from 0.30:
  * fix App::Nopaste::ssh's new filename description feature
- changes from 0.29:
  * add --private to several services
  * use Class::Load instead of require "Module/Name.pm"
  * document --list and --private options
  * less hardcoding of argument names to better support subclassing
  * new Ubuntu service (http://paste.ubuntu.com/)
  * SSH: add a small suggested Apache conf that's useful for paste directories
  * SSH: optionally use the supplied description in the paste filename
* Wed Mar 23 2011 pascal.bleser@opensuse.org
- update to 0.28:
  * if LWP is producing errors, *report them*
* Fri Mar 11 2011 pascal.bleser@opensuse.org
- update to 0.27:
  * correct path to Pastie
  * throw an error if you specify -p and files
  * remove Mathbin; doy moved it to a separate dist
* Thu Feb 24 2011 pascal.bleser@opensuse.org
- update to 0.26:
  * add --open (-o) for opening the nopaste in your browser
* Tue Jan  4 2011 pascal.bleser@opensuse.org
- update to 0.25:
  * add support for $GITHUB_USER/$GITHUB_TOKEN to Gist service
* Wed Dec 22 2010 pascal.bleser@opensuse.org
- update to 0.24:
  * Gist requires https
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Fri Nov 26 2010 pascal.bleser@opensuse.org
- update to 0.23:
  * reserve the source file's extension for ssh
  * se Config::GitLike instead of Config::INI::Reader
  * remove Rafb
  * remove Husk
- add Recommends for perl(Clipboard), perl(WWW::Pastebin::PastebinCom::Create), perl(Config::GitLike) to enable additional features
* Tue Aug 31 2010 pascal.bleser@opensuse.org
- initial package (0.22)
